@@ -2,12 +2,12 @@ param <- define_parameters(
   a = markov_cycle + 1 * 2
 )
 
-mat <- define_matrix(
+mat <- define_transition(
   1-1/a, 1/a,
   .1,    .9
 )
 
-mod <- define_model(
+mod <- define_strategy(
   transition_matrix = mat,
   A = define_state(cost = 10),
   B = define_state(cost = 2)
